@@ -1,4 +1,4 @@
-#' @title AIC.dfunc - AIC-related fit statistics for detection functions
+#' @title AIC-related fit statistics for detection functions
 #' 
 #' @description Computes AICc, AIC, or BIC for estimated distance functions.
 #' 
@@ -49,7 +49,6 @@
 #' AIC(dfunc, criterion="AIC")  # AIC
 #' AIC(dfunc, criterion="BIC")  # BIC
 #' 
-#' @keywords model
 #' @export
 
 AIC.dfunc=function (object, ..., criterion="AICc") 
@@ -66,8 +65,8 @@ AIC.dfunc=function (object, ..., criterion="AICc")
     criterion <- "AICc"
   }
     
-  p <- length(coef(object))
+  p <- length(stats::coef(object))
   ans <- -2*object$loglik + (k*p) + (k * p * (p + 1))/(n - p - 1)
   attr(ans, "criterion") <- criterion
   ans
-}
\ No newline at end of file
+}
