@@ -1,16 +1,18 @@
-#' @title colorize - Add color to result if terminal accepts it
+#' @title Add color to result if terminal accepts it
 #' 
 #' @description Add ANSI color to a string using the 
 #' \code{crayon} package, if the R environment accepts color. 
-#' This function is needed because of the need to determine whether 
-#' output can be colorized.  This determination is left up to 
-#' \code{crayon::has_color()}. 
+#' This function is needed because some  
+#' output cannot be colorized.  Color determination 
+#' is made by \code{crayon::has_color()}. 
 #' 
-#' In addition, for Rdistance results, we want to only colorize 
-#' numbers, not the reporting units.  Everything between the last set 
-#' of square brackets (\code{[...]}) is NOT colorized. 
+#' Rdistance results often include units, e.g., "25 [m]". 
+#' Only colorize the numbers, not the units.  Everything between the 
+#' first set of square brackets (\code{[...]}) is NOT colorized. 
+#' Subsequent sets of brackets (e.g., "25 [m] + 30 [ft]") ARE colorized
+#' (i.e., "[ft]" is color). 
 #' 
-#' @param STR The string to colorize. 
+#' @param STR A vector of strings to colorize. 
 #' 
 #' @param col A string specifying the desired foreground color.  
 #' This is passed straight to \code{crayon::style} and so must be 
@@ -28,7 +30,7 @@
 #' string is returned unperturbed.  If color is allowed, the input 
 #' string is returned with color and background ANSI code surrounding 
 #' the initial part of the string from character 1 to the character 
-#' before the [ in the last pair of []. 
+#' before the [ in the first pair of []. 
 #' 
 #' @seealso \code{crayon::style}
 #' 
@@ -40,19 +42,16 @@ colorize <- function(STR, col=NULL, bg = NULL){
     if( is.null(col) ){
       col <- "green"
     }
-    if(!is.na(STR)){
-      uLoc <- regexpr("\\[(?:.(?!\\[))+\\]", STR, perl = TRUE)  # last occurrence of [ to end of string
-    } else {
-      uLoc <- 0
-    }
-    if(uLoc > 0){
-      u <- substring(STR, uLoc, uLoc + attr(uLoc, "match.length"))
-      STR <- substring(STR, 1, uLoc - 1)
-    }
-    STR <- crayon::style(STR, as = col, bg = bg)
-    if(uLoc > 0){
-      STR <- paste0(STR, u)
-    }
+    uLoc <- regexpr("\\[(?:.(?!\\[))+\\]", STR, perl = TRUE)  
+    u <- substring(STR, uLoc, uLoc + attr(uLoc, "match.length"))
+    u[is.na(u)] <- ""
+    uLoc <- ifelse(uLoc < 0, nchar(STR)+1, uLoc)
+    STR1 <- substring(STR, 1, uLoc - 1)  # before [*]
+    STR2 <- substring(STR, uLoc + nchar(u)) # after [*]
+    STR2[is.na(STR2)] <- ""
+    STR1 <- crayon::style(STR1, as = col, bg = bg)
+    STR2 <- crayon::style(STR2, as = col, bg = bg)
+    STR <- paste0(STR1, u, STR2)
   } 
   STR
 }
