@@ -1,4 +1,4 @@
-#' @title intercept.only - Detect intercept-only distance function
+#' @title Detect intercept-only distance function
 #' 
 #' @description
 #' Utility function to detect whether a distance function has 
@@ -16,7 +16,7 @@
 
 intercept.only <- function(object){
   
-  mt <- terms(object$mf)
+  mt <- stats::terms(object$mf)
   if( attr(mt,"intercept") == 0 ){
     # it has no intecept, so not "intecept only"
     return(FALSE)
@@ -30,4 +30,4 @@ intercept.only <- function(object){
     return(FALSE)
   }
   
-}
\ No newline at end of file
+}
