@@ -1,4 +1,4 @@
-#' @title negexp.like - Negative exponential likelihood
+#' @title Negative exponential likelihood
 #' 
 #' @description Computes the negative exponential distance function. 
 #' 
@@ -21,10 +21,13 @@
 #' 
 #' @export
 
-negexp.like <- function (a, 
-                         dist, 
-                         covars){
+negexp.like <- function(a
+                      , dist
+                      , covars
+                      , w.hi = NULL
+                      ){
 
+  # w.hi is ignored, but needed for compatability in other likelihoods
   # What's in a? : 
   #     a = [(Intercept), b1, ..., bp, <expansion coef>]
   if(length(dim(dist)) >= 2 && dim(dist)[2] != 1 ){ 
@@ -41,17 +44,13 @@ negexp.like <- function (a,
   s <- covars %*% t(beta) # (nXq) %*% (qXk) = nXk
   sigma <- exp(s)  # link function here
 
-  dist <- units::set_units(dist, NULL)
-  dist <- matrix(dist
-                 , nrow = length(dist)
-                 , ncol = ncol(sigma)
-  ) 
-  
+  dist <- dropUnits(dist)
+
   key = -sigma * dist  # (nXk) * (nXk)
   key <- exp(key)
   
   return( list(L.unscaled = key, 
-               params = sigma)
+               params = s)
   )  
 
 }
